clear all
global J k L R  w_n p_n u_n i_n pp uu 
param;

dt=2.e-4;

T_r=0.15;
T_f=4*T_r;


nt=floor(T_f/dt);



wi=0;
ii=0;
pi=0;

wei=5;
iei=20;
pei=10;

% poles obs
r1=-(R/L)*(1+sqrt(-1))/2.;r2=-(R/L)*(1-sqrt(-1))/2.;
r3=-R/L/5.;
%gain obs
Lp=real(L*J*r1*r2*r3/k);
Lw= -k + J*L/k * real(r1*r2+r2*r3+r3*r1);
Li=R+L*real(r1+r2+r3);


figure(1);clf;
set(gcf,'renderer','openGL');

subplot(312)
axis([0 T_f 0 w_n*.6]);
hold on;
title('Vitesse mcanique (rad/s)','FontSize',20);
hw=line([0 0],[wi wi],'LineWidth',2.5);
hwe=line([0 0],[wei wei],'LineWidth',2.5,'color','g');
zoom on

subplot(311)
axis([0 T_f -0.2*i_n  3*i_n]);
hold on;
title('Courant moteur (A)','FontSize',20);
hi=line([0 0],[ii ii],'LineWidth',1.);
hie=line([0 0],[iei iei],'LineWidth',2.5,'color','g');
hif=line([0 0],[iei iei],'LineWidth',2.5,'color','r');
zoom on

subplot(313)
axis([0  T_f  -p_n  p_n]);
hold on;
title('Couple de charge (Nm)','FontSize',20);
xlabel('temps (s)','FontSize',20);
hp=line([0 0],[pi pi],'LineWidth',2.5);
hpe=line([0 0],[pei pei],'LineWidth',2.5,'color','g');
zoom on

ti=0;
w=wi;
i=ii;
iff=ii
imf=iff;
   
p=pi;
we=wei;
ie=iei;
pe=pei;
t=ti;
pause;
for iter=1:nt
   s=ti/T_r;
   s=min(1,s);
   uu=u_n*s/2.;
   
   if (ti <  T_r*1.5) 
      pp=0;
   else
      pp=p_n/2.;
   end;
      
   
   im=ii+i_n/5*randn;
   
   iff=iff+ dt*(im-iff)/0.01;
   
   imf=[imf  iff]; 
   
   dp=Lp*(iei-im);
   dw=(k*im - pei + Lw*(iei-im))/J;
   di=(-k*wei-R*iei+uu+Li*(iei-im))/L;
   
   pei=pei+dt*dp;
   wei=wei+dt*dw;
   iei=iei+dt*di;
   
   
   
   
   
   [tt xx]=ode45('dynmot',[ti ti+dt],[wi ii]);
   wi=xx(length(tt),1);
   w=[w wi];
   ii=xx(length(tt),2);
   i=[i im];
   p=[p pp];
   
   we=[we wei];
   ie=[ie iei];
   pe=[pe pei];
   
   ti=ti+dt;
   t=[t ti];
   drawnow;
   set(hw,'Xdata',t,'Ydata',w);
   set(hi,'Xdata',t,'Ydata',i);
   set(hp,'Xdata',t,'Ydata',p);
   set(hwe,'Xdata',t,'Ydata',we);
   set(hie,'Xdata',t,'Ydata',ie);
   set(hif,'Xdata',t,'Ydata',imf);
   set(hpe,'Xdata',t,'Ydata',pe);
  
end;

return





pause
subplot(211);
plot([T_f/2 T_f], [w_n/2 0],'LineWidth',2.5);

subplot(212);
plot([T_f/2 T_f], [-i_n i_n],'LineWidth',2.5);




return





[X,S] = meshgrid([0:.25:Se+1],[0:.25:Se]);
figure(1);clf;
axis([0 Se+1 0 Se]);
hold on;

%%% Create  Menu
hmenu = uimenu('Label','BIO-REACTOR');



uimenu('Parent',hmenu,'Label','D=0.6',...
   'CallBack',['flag=0;D=0.6; set(Hslider,''value'',D); cla; Vfield(X,S);'])


uimenu('Parent',hmenu,'Label','D=1',...
   'CallBack',['flag=0;D=1;set(Hslider,''value'',D); cla; Vfield(X,S);'])


uimenu('Parent',hmenu,'Label','Trajectories','Separator','on',...
   'CallBack',['traj;'])



uimenu('Parent',hmenu,'Label','Exit','Separator','on',...
   'CallBack','flag=0; close all;');



Hslider=uicontrol(figure(1),'units','normalized','style','slider','position',[.95  0.01 .02 .98],...
			'min',0.01,'max',2.,'value',1.,...
         'callback',['D=get(Hslider,''value'');'...
                      'if (D < 1); D=1 - (1-D)^3; else;D=1 + (D-1)^3; end;' ...
                  'cla; Vfield(X,S);' ...
               ]);
            
            
            Vfield(X,S);   
            
Htraj=uicontrol('units','normalized','style','push','position',[.01 .01 0.1 0.04], ....
      'string','trajectories','callback', 'traj');





return









   



